==> percona-xtrabackup-80_8.0.30-23.orig.tar.gz: percona-xtrabackup-8.0.30-23/sql/dd/object_id.h <==
/* Copyright (c) 2014, 2022, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#ifndef DD__OBJECT_ID_INCLUDED
#define DD__OBJECT_ID_INCLUDED

namespace dd {

///////////////////////////////////////////////////////////////////////////

typedef unsigned long long Object_id;

/**
  The default object ID which represents that the DD object is
  new and not persistent in dictionary tables yet.
*/
const Object_id INVALID_OBJECT_ID = (Object_id)-1;

///////////////////////////////////////////////////////////////////////////

}  // namespace dd

#endif  // DD__OBJECT_ID_INCLUDED

==> percona-xtrabackup-84_8.4.0-4.orig.tar.gz: percona-xtrabackup-8.4.0-4/sql/dd/object_id.h <==
/* Copyright (c) 2014, 2024, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

#ifndef DD__OBJECT_ID_INCLUDED
#define DD__OBJECT_ID_INCLUDED

namespace dd {

///////////////////////////////////////////////////////////////////////////

typedef unsigned long long Object_id;

/**
  The default object ID which represents that the DD object is
  new and not persistent in dictionary tables yet.
*/
const Object_id INVALID_OBJECT_ID = (Object_id)-1;

///////////////////////////////////////////////////////////////////////////

}  // namespace dd

#endif  // DD__OBJECT_ID_INCLUDED
